@@ -107,14 +107,17 @@ setMethod("[", "SpatialPolygonsDataFrame", function(x, i, j, ... , drop = TRUE)
 
 	y@polygons = x@polygons[i]
 #	x@bbox <- .bboxCalcR(x@polygons)
-        y@bbox <- .Call(bboxCalcR_c, y@polygons)
-        if (is.numeric(i) && i < 0) {
-#             area <- sapply(x@polygons, function(y) y@area)
-#             x@plotOrder <- as.integer(order(area, decreasing=TRUE))
-              y@plotOrder <- .Call(SpatialPolygons_plotOrder_c, y@polygons)
-        } else {
-	    y@plotOrder = order(match(i, x@plotOrder))
-        }
+	if (length(i) > 0) {
+            y@bbox <- .Call(bboxCalcR_c, y@polygons)
+            if (is.numeric(i) && i < 0) {
+#                 area <- sapply(x@polygons, function(y) y@area)
+#                 x@plotOrder <- as.integer(order(area, decreasing=TRUE))
+                  y@plotOrder <- .Call(SpatialPolygons_plotOrder_c, y@polygons)
+            } else {
+	        y@plotOrder = order(match(i, x@plotOrder))
+            }
+	} else
+	    y@bbox = x@bbox
 	y
 ###
 ### RSB: do something with labelpoints here? How can I check they are present?
@@ -133,3 +136,14 @@ setMethod("geometry", "SpatialPolygonsDataFrame",
 	function(obj) as(obj, "SpatialPolygons"))
 
 length.SpatialPolygonsDataFrame = function(x) { length(x@polygons) }
+
+# RSB 151030 override default coerce to preserve top-level comment
+setAs("SpatialPolygonsDataFrame", "SpatialPolygons",
+    function(from) {
+        value <- new("SpatialPolygons")
+        for (what in c("polygons", "plotOrder", "bbox", "proj4string"
+            )) slot(value, what) <- slot(from, what)
+        if (!is.null(comment(from))) comment(value) <- comment(from)
+        value
+    }
+)
